==> 0.11.1.tar.gz: lib/models/subscription_view_response.dart <==
class SubscriptionViewResponse {
  String? statusCode;
  String? message;
  Rows? rows;
  int? total;

  SubscriptionViewResponse(
      {this.statusCode, this.message, this.rows, this.total});

  SubscriptionViewResponse.fromJson(Map<String, dynamic> json) {
    statusCode = json['statusCode'];
    message = json['message'];
    rows = json['rows'] != null ? new Rows.fromJson(json['rows']) : null;
    total = json['total'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['statusCode'] = this.statusCode;
    data['message'] = this.message;
    if (this.rows != null) {
      data['rows'] = this.rows!.toJson();
    }
    data['total'] = this.total;
    return data;
  }
}

class Rows {
  AccountingDetails? accountingDetails;
  String? partnerDetails;
  List<String>? subscriptionsList;
  String? lastSubscriptionDetails;
  double? outstandingAmount;
  int? subscriptionDemoForDays;

  Rows(
      {this.accountingDetails,
      this.partnerDetails,
      this.subscriptionsList,
      this.lastSubscriptionDetails,
      this.outstandingAmount,
      this.subscriptionDemoForDays});

  Rows.fromJson(Map<String, dynamic> json) {
    accountingDetails = json['accounting_details'] != null
        ? new AccountingDetails.fromJson(json['accounting_details'])
        : null;
    partnerDetails = json['partner_details'];
    subscriptionsList = json['subscriptions_list'].cast<String>();
    lastSubscriptionDetails = json['last_subscription_details'];
    outstandingAmount = json['outstanding_amount'];
    subscriptionDemoForDays = json['subscription_demo_for_days'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.accountingDetails != null) {
      data['accounting_details'] = this.accountingDetails!.toJson();
    }
    data['partner_details'] = this.partnerDetails;
    data['subscriptions_list'] = this.subscriptionsList;
    data['last_subscription_details'] = this.lastSubscriptionDetails;
    data['outstanding_amount'] = this.outstandingAmount;
    data['subscription_demo_for_days'] = this.subscriptionDemoForDays;
    return data;
  }
}

class AccountingDetails {
  String? accountNumber;
  String? billingAddress;
  String? gst;

  AccountingDetails({this.accountNumber, this.billingAddress, this.gst});

  AccountingDetails.fromJson(Map<String, dynamic> json) {
    accountNumber = json['account_number'];
    billingAddress = json['billing_address'];
    gst = json['gst'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['account_number'] = this.accountNumber;
    data['billing_address'] = this.billingAddress;
    data['gst'] = this.gst;
    return data;
  }
}

==> 0.22.5.tar.gz: lib/models/subscription_view_response.dart <==
class SubscriptionViewResponse {
  String? statusCode;
  String? message;
  Rows? rows;
  int? total;

  SubscriptionViewResponse(
      {this.statusCode, this.message, this.rows, this.total});

  SubscriptionViewResponse.fromJson(Map<String, dynamic> json) {
    statusCode = json['statusCode'];
    message = json['message'];
    rows = json['rows'] != null ? new Rows.fromJson(json['rows']) : null;
    total = json['total'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['statusCode'] = this.statusCode;
    data['message'] = this.message;
    if (this.rows != null) {
      data['rows'] = this.rows!.toJson();
    }
    data['total'] = this.total;
    return data;
  }
}

class Rows {
  AccountingDetails? accountingDetails;
  String? partnerDetails;
  List<String>? subscriptionsList;
  LastSubscriptionDetails? lastSubscriptionDetails;
  double? outstandingAmount;
  int? subscriptionDemoForDays;

  Rows(
      {this.accountingDetails,
      this.partnerDetails,
      this.subscriptionsList,
      this.lastSubscriptionDetails,
      this.outstandingAmount,
      this.subscriptionDemoForDays});

  Rows.fromJson(Map<String, dynamic> json) {
    accountingDetails = json['accounting_details'] != null
        ? new AccountingDetails.fromJson(json['accounting_details'])
        : null;
    partnerDetails = json['partner_details'];
    subscriptionsList = json['subscriptions_list'].cast<String>();
    lastSubscriptionDetails = json['last_subscription_details'] != null
        ? new LastSubscriptionDetails.fromJson(json['last_subscription_details'])
        : null;
    outstandingAmount = json['outstanding_amount'];
    subscriptionDemoForDays = json['subscription_demo_for_days'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.accountingDetails != null) {
      data['accounting_details'] = this.accountingDetails!.toJson();
    }
    if (this.lastSubscriptionDetails != null) {
      data['last_subscription_details'] = this.lastSubscriptionDetails!.toJson();
    }
    data['partner_details'] = this.partnerDetails;
    data['subscriptions_list'] = this.subscriptionsList;
    data['outstanding_amount'] = this.outstandingAmount;
    data['subscription_demo_for_days'] = this.subscriptionDemoForDays;
    return data;
  }
}

class LastSubscriptionDetails {
  int? id;
  int? subscriptionActiveFromDate;
  int? subscriptionValidTillDate;
  int? subscribedForDays;
  int? remainingDays;
  String? subscriptionStatus;

  LastSubscriptionDetails(
      {this.id,
        this.subscriptionActiveFromDate,
        this.subscriptionValidTillDate,
        this.subscribedForDays,
        this.remainingDays,
        this.subscriptionStatus});

  LastSubscriptionDetails.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    subscriptionActiveFromDate = json['subscription_active_from_date'];
    subscriptionValidTillDate = json['subscription_valid_till_date'];
    subscribedForDays = json['subscribed_for_days'];
    remainingDays = json['remaining_days'];
    subscriptionStatus = json['subscription_status'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['subscription_active_from_date'] = this.subscriptionActiveFromDate;
    data['subscription_valid_till_date'] = this.subscriptionValidTillDate;
    data['subscribed_for_days'] = this.subscribedForDays;
    data['remaining_days'] = this.remainingDays;
    data['subscription_status'] = this.subscriptionStatus;
    return data;
  }
}

class AccountingDetails {
  String? accountNumber;
  String? billingAddress;
  String? gst;

  AccountingDetails({this.accountNumber, this.billingAddress, this.gst});

  AccountingDetails.fromJson(Map<String, dynamic> json) {
    accountNumber = json['account_number'];
    billingAddress = json['billing_address'];
    gst = json['gst'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['account_number'] = this.accountNumber;
    data['billing_address'] = this.billingAddress;
    data['gst'] = this.gst;
    return data;
  }
}
